@@ -20,14 +20,14 @@
 #'
 #' @examples
 #' co <- complexity_outlook(
-#'  economiccomplexity_output$balassa_index,
-#'  economiccomplexity_output$proximity$proximity_product,
-#'  economiccomplexity_output$complexity_measures$complexity_index_product
+#'   economiccomplexity_output$balassa_index,
+#'   economiccomplexity_output$proximity$proximity_product,
+#'   economiccomplexity_output$complexity_measures$complexity_index_product
 #' )
 #'
 #' # partial view of complexity outlook
 #' co$complexity_outlook_index[1:5]
-#' co$complexity_outlook_gain[1:5,1:5]
+#' co$complexity_outlook_gain[1:5, 1:5]
 #'
 #' @references
 #' For more information on this index see:
@@ -59,8 +59,10 @@ complexity_outlook <- function(balassa_index, proximity_product, complexity_inde
 
   coi <- colSums(t((1 - dist) * (1 - balassa_index)) * complexity_index_product)
 
-  cog <- (1 - balassa_index) * tcrossprod((1 - balassa_index),
-    t(proximity_product * (complexity_index_product / rowSums(proximity_product))))
+  cog <- (1 - balassa_index) * tcrossprod(
+    (1 - balassa_index),
+    t(proximity_product * (complexity_index_product / rowSums(proximity_product)))
+  )
 
   return(
     list(
